@@ -44,14 +44,14 @@ class Timer:
         self._verbose = verbose
         self.results: List[TimerResult] = []
 
-    def __call__(self, name: Optional[str] = None, verbose: Optional[bool] = None) -> Timer:
+    def __call__(self, name: Optional[str] = None, verbose: Optional[bool] = None):
         if name:
             self._name = name
         if verbose is not None:
             self._verbose = verbose
         return self
 
-    def start(self, name: Optional[str] = None, verbose: Optional[bool] = None) -> Timer:
+    def start(self, name: Optional[str] = None, verbose: Optional[bool] = None):
         self.results.append(TimerResult(name or self._name, self._verbose if verbose is None else verbose))
         return self
 
